
from distutils.core import setup
setup(
  name = 'poopy_project',
  packages = ['poopy_project'],
  version = '0.0.0.20',
  description = 'I make poopy',
  author = 'Winnie The Poo',
  author_email = 'poo-delivery@hotmail.com',
  keywords = ["poo", "slushy", "relief"],
  classifiers = []
)